unit Entidade.Base_Nuvem_Usuario;

interface

uses
  SysUtils,
  Generics.Collections,
  Aurelius.Mapping.Attributes,
  Aurelius.Types.Blob,
  Aurelius.Types.DynamicProperties,
  Aurelius.Types.Nullable,
  Aurelius.Types.Proxy,
  Aurelius.Criteria.Dictionary;

type
  TConexao = class;
  TEmail = class;
  TEndereco = class;
  TEstabelecimento = class;
  TGrupoEstabelecimento = class;
  TIdentificador = class;
  TTelefone = class;
  TToken = class;
  TUsuario = class;
  TUsuarioAdc = class;
  TUsuarioTableDictionary = class;
  TIdentificadorTableDictionary = class;
  TConexaoTableDictionary = class;
  TEmailTableDictionary = class;
  TTelefoneTableDictionary = class;
  TUsuarioAdcTableDictionary = class;
  TGrupoEstabelecimentoTableDictionary = class;
  TEstabelecimentoTableDictionary = class;
  TTokenTableDictionary = class;
  TEnderecoTableDictionary = class;

  [Entity]
  [Table('conexao')]
  [Id('FIdUrlConexao', TIdGenerator.Guid)]
  TConexao = class
  private
    [Column('id_url_conexao', [TColumnProp.Required])]
    FIdUrlConexao: TGuid;

    [Column('url', [TColumnProp.Required], 50)]
    FUrl: string;

    [Association([TAssociationProp.Lazy], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('fk_usuario', [], 'id_usuario')]
    FFkUsuario: Proxy<TUsuario>;

    [Association([TAssociationProp.Lazy], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('fk_estabelecimento', [], 'id_estabelecimento')]
    FFkEstabelecimento: Proxy<TEstabelecimento>;
    function GetFkUsuario: TUsuario;
    procedure SetFkUsuario(const Value: TUsuario);
    function GetFkEstabelecimento: TEstabelecimento;
    procedure SetFkEstabelecimento(const Value: TEstabelecimento);
  public
    property IdUrlConexao: TGuid read FIdUrlConexao write FIdUrlConexao;
    property Url: string read FUrl write FUrl;
    property FkUsuario: TUsuario read GetFkUsuario write SetFkUsuario;
    property FkEstabelecimento: TEstabelecimento read GetFkEstabelecimento write SetFkEstabelecimento;
  end;

  [Entity]
  [Table('email')]
  [Id('FIdEmail', TIdGenerator.Guid)]
  TEmail = class
  private
    [Column('id_email', [TColumnProp.Required])]
    FIdEmail: TGuid;

    [Column('email', [], 50)]
    FEmail: string;

    [Column('identificador', [])]
    FIdentificador: Integer;

    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('fk_usuario', [TColumnProp.Required], 'id_usuario')]
    FFkUsuario: Proxy<TUsuario>;
    function GetFkUsuario: TUsuario;
    procedure SetFkUsuario(const Value: TUsuario);
  public
    property IdEmail: TGuid read FIdEmail write FIdEmail;
    property Email: string read FEmail write FEmail;
    property Identificador: Integer read FIdentificador write FIdentificador;
    property FkUsuario: TUsuario read GetFkUsuario write SetFkUsuario;
  end;

  [Entity]
  [Table('endereco')]
  [Id('FIdEndereco', TIdGenerator.Guid)]
  TEndereco = class
  private
    [Column('id_endereco', [TColumnProp.Required])]
    FIdEndereco: TGuid;

    [Column('descricao', [], 50)]
    FDescricao: string;

    [Column('cep', [], 12)]
    FCep: string;

    [Column('logradouro', [], 100)]
    FLogradouro: string;

    [Column('numero', [], 10)]
    FNumero: string;

    [Column('bairro', [], 50)]
    FBairro: string;

    [Column('cidade', [], 50)]
    FCidade: string;

    [Column('complemento', [], 50)]
    FComplemento: string;

    [Column('referencia', [], 50)]
    FReferencia: string;

    [Column('uf', [], 4)]
    FUf: string;

    [Column('ibge', [], 10)]
    FIbge: string;

    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('fk_usuario', [TColumnProp.Required], 'id_usuario')]
    FFkUsuario: Proxy<TUsuario>;
    function GetFkUsuario: TUsuario;
    procedure SetFkUsuario(const Value: TUsuario);
  public
    property IdEndereco: TGuid read FIdEndereco write FIdEndereco;
    property Descricao: string read FDescricao write FDescricao;
    property Cep: string read FCep write FCep;
    property Logradouro: string read FLogradouro write FLogradouro;
    property Numero: string read FNumero write FNumero;
    property Bairro: string read FBairro write FBairro;
    property Cidade: string read FCidade write FCidade;
    property Complemento: string read FComplemento write FComplemento;
    property Referencia: string read FReferencia write FReferencia;
    property Uf: string read FUf write FUf;
    property Ibge: string read FIbge write FIbge;
    property FkUsuario: TUsuario read GetFkUsuario write SetFkUsuario;
  end;

  [Entity]
  [Table('estabelecimento')]
  [Id('FIdEstabelecimento', TIdGenerator.Guid)]
  TEstabelecimento = class
  private
    [Column('id_estabelecimento', [TColumnProp.Required])]
    FIdEstabelecimento: TGuid;

    [Column('classe', [])]
    FClasse: Integer;

    [Column('cnpj_cpf', [], 20)]
    FCnpjCpf: string;

    [Column('razao', [TColumnProp.Required], 50)]
    FRazao: string;

    [Column('fantasia', [], 50)]
    FFantasia: string;

    [Column('ie', [], 15)]
    FIe: string;

    [Column('im', [], 15)]
    FIm: string;

    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('fk_grupo_estabelecimento', [TColumnProp.Required], 'id_grupo_estabelecimento')]
    FFkGrupoEstabelecimento: Proxy<TGrupoEstabelecimento>;

    [ManyValuedAssociation([], [TCascadeType.SaveUpdate, TCascadeType.Merge, TCascadeType.Remove], 'FFkEstabelecimento')]
    FListaConexao: TList<TConexao>;
    function GetFkGrupoEstabelecimento: TGrupoEstabelecimento;
    procedure SetFkGrupoEstabelecimento(const Value: TGrupoEstabelecimento);
  public
    constructor Create;
    destructor Destroy; override;
    property IdEstabelecimento: TGuid read FIdEstabelecimento write FIdEstabelecimento;
    property Classe: Integer read FClasse write FClasse;
    property CnpjCpf: string read FCnpjCpf write FCnpjCpf;
    property Razao: string read FRazao write FRazao;
    property Fantasia: string read FFantasia write FFantasia;
    property Ie: string read FIe write FIe;
    property Im: string read FIm write FIm;
    property FkGrupoEstabelecimento: TGrupoEstabelecimento read GetFkGrupoEstabelecimento write SetFkGrupoEstabelecimento;
    property ListaConexao: TList<TConexao> read FListaConexao;
  end;

  [Entity]
  [Table('grupo_estabelecimento')]
  [Id('FIdGrupoEstabelecimento', TIdGenerator.Guid)]
  TGrupoEstabelecimento = class
  private
    [Column('id_grupo_estabelecimento', [TColumnProp.Required])]
    FIdGrupoEstabelecimento: TGuid;

    [Column('descricao', [TColumnProp.Required], 50)]
    FDescricao: string;
  public
    property IdGrupoEstabelecimento: TGuid read FIdGrupoEstabelecimento write FIdGrupoEstabelecimento;
    property Descricao: string read FDescricao write FDescricao;
  end;

  [Entity]
  [Table('identificador')]
  [Id('FIdFuncao', TIdGenerator.Guid)]
  TIdentificador = class
  private
    [Column('id_funcao', [TColumnProp.Required])]
    FIdFuncao: TGuid;

    [Column('identificador', [TColumnProp.Required])]
    FIdentificador: Integer;

    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('fk_usuario', [TColumnProp.Required], 'id_usuario')]
    FFkUsuario: Proxy<TUsuario>;
    function GetFkUsuario: TUsuario;
    procedure SetFkUsuario(const Value: TUsuario);
  public
    property IdFuncao: TGuid read FIdFuncao write FIdFuncao;
    property Identificador: Integer read FIdentificador write FIdentificador;
    property FkUsuario: TUsuario read GetFkUsuario write SetFkUsuario;
  end;

  [Entity]
  [Table('telefone')]
  [Id('FIdTelefone', TIdGenerator.Guid)]
  TTelefone = class
  private
    [Column('id_telefone', [TColumnProp.Required])]
    FIdTelefone: TGuid;

    [Column('cod_pais', [], 5)]
    FCodPais: string;

    [Column('ddd', [], 4)]
    FDdd: string;

    [Column('telefone', [], 15)]
    FTelefone: string;

    [Column('identificador', [])]
    FIdentificador: Integer;

    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    //TESTE, VALMIR
    [JoinColumn('fk_usuario', [TColumnProp.Required], 'id_usuario')]
    FFkUsuario: Proxy<TUsuario>;
    function GetFkUsuario: TUsuario;
    procedure SetFkUsuario(const Value: TUsuario);
  public
    property IdTelefone: TGuid read FIdTelefone write FIdTelefone;
    property CodPais: string read FCodPais write FCodPais;
    property Ddd: string read FDdd write FDdd;
    property Telefone: string read FTelefone write FTelefone;
    property Identificador: Integer read FIdentificador write FIdentificador;
    property FkUsuario: TUsuario read GetFkUsuario write SetFkUsuario;
  end;

  [Entity]
  [Table('token')]
  [Id('FIdToken', TIdGenerator.Guid)]
  TToken = class
  private
    [Column('id_token', [TColumnProp.Required])]
    FIdToken: TGuid;

    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('fk_usuario', [TColumnProp.Required], 'id_usuario')]
    FFkUsuario: Proxy<TUsuario>;

    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('fk_estabelecimento', [TColumnProp.Required], 'id_estabelecimento')]
    FFkEstabelecimento: Proxy<TEstabelecimento>;
    function GetFkUsuario: TUsuario;
    procedure SetFkUsuario(const Value: TUsuario);
    function GetFkEstabelecimento: TEstabelecimento;
    procedure SetFkEstabelecimento(const Value: TEstabelecimento);
  public
    property IdToken: TGuid read FIdToken write FIdToken;
    property FkUsuario: TUsuario read GetFkUsuario write SetFkUsuario;
    property FkEstabelecimento: TEstabelecimento read GetFkEstabelecimento write SetFkEstabelecimento;
  end;

  [Entity]
  [Table('usuario')]
  [Id('FIdUsuario', TIdGenerator.Guid)]
  TUsuario = class
  private
    [Column('id_usuario', [TColumnProp.Required])]
    FIdUsuario: TGuid;

    [Column('codigo', [], 20)]
    FCodigo: string;

    [Column('classe', [])]
    FClasse: Integer;

    [Column('nome_razao', [TColumnProp.Required], 50)]
    FNomeRazao: string;

    [Column('fantasia', [], 50)]
    FFantasia: string;

    [Column('cpf_cnpj', [], 20)]
    FCpfCnpj: string;

    [Column('rg_ie', [], 20)]
    FRgIe: string;

    [Column('status', [])]
    FStatus: Integer;

    [Column('sexo', [], 1)]
    FSexo: string;

    [Column('senha', [], 30)]
    FSenha: string;

    [Column('fk_token', [])]
    FFkToken: TGuid;

    [Association([TAssociationProp.Lazy], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('fk_usuario_adc', [], 'id_usuario_adc')]
    FFkUsuarioAdc: Proxy<TUsuarioAdc>;

    [ManyValuedAssociation([TAssociationProp.Required], [TCascadeType.SaveUpdate, TCascadeType.Merge, TCascadeType.Remove], 'FFkUsuario')]
    FListaIdentificador: TList<TIdentificador>;

    [ManyValuedAssociation([], [TCascadeType.SaveUpdate, TCascadeType.Merge, TCascadeType.Remove], 'FFkUsuario')]
    FListaConexao: TList<TConexao>;

    [ManyValuedAssociation([TAssociationProp.Required], [TCascadeType.SaveUpdate, TCascadeType.Merge, TCascadeType.Remove], 'FFkUsuario')]
    //    [ManyValuedAssociation([TAssociationProp.Required], CascadeTypeAllRemoveOrphan, 'FFkUsuario')]
    FListaEmail: TList<TEmail>;

    [ManyValuedAssociation([TAssociationProp.Required], [TCascadeType.SaveUpdate, TCascadeType.Merge, TCascadeType.Remove], 'FFkUsuario')]
    //    [ManyValuedAssociation([TAssociationProp.Required], CascadeTypeAllRemoveOrphan, 'FFkUsuario')]
    FListaTelefone: TList<TTelefone>;

    [ManyValuedAssociation([TAssociationProp.Required], [TCascadeType.SaveUpdate, TCascadeType.Merge, TCascadeType.Remove], 'FFkUsuario')]
    //    [ManyValuedAssociation([TAssociationProp.Required], CascadeTypeAllRemoveOrphan, 'FFkUsuario')]
    FListaEndereco: TList<TEndereco>;
    function GetFkUsuarioAdc: TUsuarioAdc;
    procedure SetFkUsuarioAdc(const Value: TUsuarioAdc);
  public
    constructor Create;
    destructor Destroy; override;
    property IdUsuario: TGuid read FIdUsuario write FIdUsuario;
    property Codigo: string read FCodigo write FCodigo;
    property Classe: Integer read FClasse write FClasse;
    property NomeRazao: string read FNomeRazao write FNomeRazao;
    property Fantasia: string read FFantasia write FFantasia;
    property CpfCnpj: string read FCpfCnpj write FCpfCnpj;
    property RgIe: string read FRgIe write FRgIe;
    property Status: Integer read FStatus write FStatus;
    property Sexo: string read FSexo write FSexo;
    property Senha: string read FSenha write FSenha;
    property FkToken: TGuid read FFkToken write FFkToken;
    property FkUsuarioAdc: TUsuarioAdc read GetFkUsuarioAdc write SetFkUsuarioAdc;
    property ListaIdentificador: TList<TIdentificador> read FListaIdentificador;
    property ListaConexao: TList<TConexao> read FListaConexao;
    property ListaEmail: TList<TEmail> read FListaEmail;
    property ListaTelefone: TList<TTelefone> read FListaTelefone;
    property ListaEndereco: TList<TEndereco> read FListaEndereco;
  end;

  [Entity]
  [Table('usuario_adc')]
  [Id('FIdUsuarioAdc', TIdGenerator.Guid)]
  TUsuarioAdc = class
  private
    [Column('id_usuario_adc', [TColumnProp.Required])]
    FIdUsuarioAdc: TGuid;

    [Column('ind_ie', [])]
    FIndIe: Integer;

    [Column('inscricao_municipal', [], 20)]
    FInscricaoMunicipal: string;

    [Column('dt_cadastro', [])]
    FDtCadastro: TDateTime;

    [Column('dt_nascimento', [])]
    FDtNascimento: TDateTime;

    [Column('dt_admissao_funcionario', [])]
    FDtAdmissaoFuncionario: TDateTime;

    [Column('dt_demissao_funcionario', [])]
    FDtDemissaoFuncionario: TDateTime;

    [Column('comissao_funcionario', [], 10, 2)]
    FComissaoFuncionario: Double;

    [Column('salario_funcionario', [], 10, 2)]
    FSalarioFuncionario: Double;

    [Column('funcao_funcionario', [])]
    FFuncaoFuncionario: Integer;

    [Column('nivel_usuario', [])]
    FNivelUsuario: Integer;

    [Column('personalizado_usuario', [], 1)]
    FPersonalizadoUsuario: string;
  public
    property IdUsuarioAdc: TGuid read FIdUsuarioAdc write FIdUsuarioAdc;
    property IndIe: Integer read FIndIe write FIndIe;
    property InscricaoMunicipal: string read FInscricaoMunicipal write FInscricaoMunicipal;
    property DtCadastro: TDateTime read FDtCadastro write FDtCadastro;
    property DtNascimento: TDateTime read FDtNascimento write FDtNascimento;
    property DtAdmissaoFuncionario: TDateTime read FDtAdmissaoFuncionario write FDtAdmissaoFuncionario;
    property DtDemissaoFuncionario: TDateTime read FDtDemissaoFuncionario write FDtDemissaoFuncionario;
    property ComissaoFuncionario: Double read FComissaoFuncionario write FComissaoFuncionario;
    property SalarioFuncionario: Double read FSalarioFuncionario write FSalarioFuncionario;
    property FuncaoFuncionario: Integer read FFuncaoFuncionario write FFuncaoFuncionario;
    property NivelUsuario: Integer read FNivelUsuario write FNivelUsuario;
    property PersonalizadoUsuario: string read FPersonalizadoUsuario write FPersonalizadoUsuario;
  end;

  TDicDictionary = class
  private
    FUsuario: TUsuarioTableDictionary;
    FIdentificador: TIdentificadorTableDictionary;
    FConexao: TConexaoTableDictionary;
    FEmail: TEmailTableDictionary;
    FTelefone: TTelefoneTableDictionary;
    FUsuarioAdc: TUsuarioAdcTableDictionary;
    FGrupoEstabelecimento: TGrupoEstabelecimentoTableDictionary;
    FEstabelecimento: TEstabelecimentoTableDictionary;
    FToken: TTokenTableDictionary;
    FEndereco: TEnderecoTableDictionary;
    function GetUsuario: TUsuarioTableDictionary;
    function GetIdentificador: TIdentificadorTableDictionary;
    function GetConexao: TConexaoTableDictionary;
    function GetEmail: TEmailTableDictionary;
    function GetTelefone: TTelefoneTableDictionary;
    function GetUsuarioAdc: TUsuarioAdcTableDictionary;
    function GetGrupoEstabelecimento: TGrupoEstabelecimentoTableDictionary;
    function GetEstabelecimento: TEstabelecimentoTableDictionary;
    function GetToken: TTokenTableDictionary;
    function GetEndereco: TEnderecoTableDictionary;
  public
    destructor Destroy; override;
    property Usuario: TUsuarioTableDictionary read GetUsuario;
    property Identificador: TIdentificadorTableDictionary read GetIdentificador;
    property Conexao: TConexaoTableDictionary read GetConexao;
    property Email: TEmailTableDictionary read GetEmail;
    property Telefone: TTelefoneTableDictionary read GetTelefone;
    property UsuarioAdc: TUsuarioAdcTableDictionary read GetUsuarioAdc;
    property GrupoEstabelecimento: TGrupoEstabelecimentoTableDictionary read GetGrupoEstabelecimento;
    property Estabelecimento: TEstabelecimentoTableDictionary read GetEstabelecimento;
    property Token: TTokenTableDictionary read GetToken;
    property Endereco: TEnderecoTableDictionary read GetEndereco;
  end;

  TUsuarioTableDictionary = class
  private
    FIdUsuario: TDictionaryAttribute;
    FCodigo: TDictionaryAttribute;
    FClasse: TDictionaryAttribute;
    FNomeRazao: TDictionaryAttribute;
    FFantasia: TDictionaryAttribute;
    FCpfCnpj: TDictionaryAttribute;
    FRgIe: TDictionaryAttribute;
    FStatus: TDictionaryAttribute;
    FSexo: TDictionaryAttribute;
    FSenha: TDictionaryAttribute;
    FFkToken: TDictionaryAttribute;
    FFkUsuarioAdc: TDictionaryAssociation;
  public
    constructor Create;
    property IdUsuario: TDictionaryAttribute read FIdUsuario;
    property Codigo: TDictionaryAttribute read FCodigo;
    property Classe: TDictionaryAttribute read FClasse;
    property NomeRazao: TDictionaryAttribute read FNomeRazao;
    property Fantasia: TDictionaryAttribute read FFantasia;
    property CpfCnpj: TDictionaryAttribute read FCpfCnpj;
    property RgIe: TDictionaryAttribute read FRgIe;
    property Status: TDictionaryAttribute read FStatus;
    property Sexo: TDictionaryAttribute read FSexo;
    property Senha: TDictionaryAttribute read FSenha;
    property FkToken: TDictionaryAttribute read FFkToken;
    property FkUsuarioAdc: TDictionaryAssociation read FFkUsuarioAdc;
  end;

  TIdentificadorTableDictionary = class
  private
    FIdFuncao: TDictionaryAttribute;
    FIdentificador: TDictionaryAttribute;
    FFkUsuario: TDictionaryAssociation;
  public
    constructor Create;
    property IdFuncao: TDictionaryAttribute read FIdFuncao;
    property Identificador: TDictionaryAttribute read FIdentificador;
    property FkUsuario: TDictionaryAssociation read FFkUsuario;
  end;

  TConexaoTableDictionary = class
  private
    FIdUrlConexao: TDictionaryAttribute;
    FUrl: TDictionaryAttribute;
    FFkUsuario: TDictionaryAssociation;
    FFkEstabelecimento: TDictionaryAssociation;
  public
    constructor Create;
    property IdUrlConexao: TDictionaryAttribute read FIdUrlConexao;
    property Url: TDictionaryAttribute read FUrl;
    property FkUsuario: TDictionaryAssociation read FFkUsuario;
    property FkEstabelecimento: TDictionaryAssociation read FFkEstabelecimento;
  end;

  TEmailTableDictionary = class
  private
    FIdEmail: TDictionaryAttribute;
    FEmail: TDictionaryAttribute;
    FIdentificador: TDictionaryAttribute;
    FFkUsuario: TDictionaryAssociation;
  public
    constructor Create;
    property IdEmail: TDictionaryAttribute read FIdEmail;
    property Email: TDictionaryAttribute read FEmail;
    property Identificador: TDictionaryAttribute read FIdentificador;
    property FkUsuario: TDictionaryAssociation read FFkUsuario;
  end;

  TTelefoneTableDictionary = class
  private
    FIdTelefone: TDictionaryAttribute;
    FCodPais: TDictionaryAttribute;
    FDdd: TDictionaryAttribute;
    FTelefone: TDictionaryAttribute;
    FIdentificador: TDictionaryAttribute;
    FFkUsuario: TDictionaryAssociation;
  public
    constructor Create;
    property IdTelefone: TDictionaryAttribute read FIdTelefone;
    property CodPais: TDictionaryAttribute read FCodPais;
    property Ddd: TDictionaryAttribute read FDdd;
    property Telefone: TDictionaryAttribute read FTelefone;
    property Identificador: TDictionaryAttribute read FIdentificador;
    property FkUsuario: TDictionaryAssociation read FFkUsuario;
  end;

  TUsuarioAdcTableDictionary = class
  private
    FIdUsuarioAdc: TDictionaryAttribute;
    FIndIe: TDictionaryAttribute;
    FInscricaoMunicipal: TDictionaryAttribute;
    FDtCadastro: TDictionaryAttribute;
    FDtNascimento: TDictionaryAttribute;
    FDtAdmissaoFuncionario: TDictionaryAttribute;
    FDtDemissaoFuncionario: TDictionaryAttribute;
    FComissaoFuncionario: TDictionaryAttribute;
    FSalarioFuncionario: TDictionaryAttribute;
    FFuncaoFuncionario: TDictionaryAttribute;
    FNivelUsuario: TDictionaryAttribute;
    FPersonalizadoUsuario: TDictionaryAttribute;
  public
    constructor Create;
    property IdUsuarioAdc: TDictionaryAttribute read FIdUsuarioAdc;
    property IndIe: TDictionaryAttribute read FIndIe;
    property InscricaoMunicipal: TDictionaryAttribute read FInscricaoMunicipal;
    property DtCadastro: TDictionaryAttribute read FDtCadastro;
    property DtNascimento: TDictionaryAttribute read FDtNascimento;
    property DtAdmissaoFuncionario: TDictionaryAttribute read FDtAdmissaoFuncionario;
    property DtDemissaoFuncionario: TDictionaryAttribute read FDtDemissaoFuncionario;
    property ComissaoFuncionario: TDictionaryAttribute read FComissaoFuncionario;
    property SalarioFuncionario: TDictionaryAttribute read FSalarioFuncionario;
    property FuncaoFuncionario: TDictionaryAttribute read FFuncaoFuncionario;
    property NivelUsuario: TDictionaryAttribute read FNivelUsuario;
    property PersonalizadoUsuario: TDictionaryAttribute read FPersonalizadoUsuario;
  end;

  TGrupoEstabelecimentoTableDictionary = class
  private
    FIdGrupoEstabelecimento: TDictionaryAttribute;
    FDescricao: TDictionaryAttribute;
  public
    constructor Create;
    property IdGrupoEstabelecimento: TDictionaryAttribute read FIdGrupoEstabelecimento;
    property Descricao: TDictionaryAttribute read FDescricao;
  end;

  TEstabelecimentoTableDictionary = class
  private
    FIdEstabelecimento: TDictionaryAttribute;
    FClasse: TDictionaryAttribute;
    FCnpjCpf: TDictionaryAttribute;
    FRazao: TDictionaryAttribute;
    FFantasia: TDictionaryAttribute;
    FIe: TDictionaryAttribute;
    FIm: TDictionaryAttribute;
    FFkGrupoEstabelecimento: TDictionaryAssociation;
  public
    constructor Create;
    property IdEstabelecimento: TDictionaryAttribute read FIdEstabelecimento;
    property Classe: TDictionaryAttribute read FClasse;
    property CnpjCpf: TDictionaryAttribute read FCnpjCpf;
    property Razao: TDictionaryAttribute read FRazao;
    property Fantasia: TDictionaryAttribute read FFantasia;
    property Ie: TDictionaryAttribute read FIe;
    property Im: TDictionaryAttribute read FIm;
    property FkGrupoEstabelecimento: TDictionaryAssociation read FFkGrupoEstabelecimento;
  end;

  TTokenTableDictionary = class
  private
    FIdToken: TDictionaryAttribute;
    FFkUsuario: TDictionaryAssociation;
    FFkEstabelecimento: TDictionaryAssociation;
  public
    constructor Create;
    property IdToken: TDictionaryAttribute read FIdToken;
    property FkUsuario: TDictionaryAssociation read FFkUsuario;
    property FkEstabelecimento: TDictionaryAssociation read FFkEstabelecimento;
  end;

  TEnderecoTableDictionary = class
  private
    FIdEndereco: TDictionaryAttribute;
    FDescricao: TDictionaryAttribute;
    FCep: TDictionaryAttribute;
    FLogradouro: TDictionaryAttribute;
    FNumero: TDictionaryAttribute;
    FBairro: TDictionaryAttribute;
    FCidade: TDictionaryAttribute;
    FComplemento: TDictionaryAttribute;
    FReferencia: TDictionaryAttribute;
    FUf: TDictionaryAttribute;
    FIbge: TDictionaryAttribute;
    FFkUsuario: TDictionaryAssociation;
  public
    constructor Create;
    property IdEndereco: TDictionaryAttribute read FIdEndereco;
    property Descricao: TDictionaryAttribute read FDescricao;
    property Cep: TDictionaryAttribute read FCep;
    property Logradouro: TDictionaryAttribute read FLogradouro;
    property Numero: TDictionaryAttribute read FNumero;
    property Bairro: TDictionaryAttribute read FBairro;
    property Cidade: TDictionaryAttribute read FCidade;
    property Complemento: TDictionaryAttribute read FComplemento;
    property Referencia: TDictionaryAttribute read FReferencia;
    property Uf: TDictionaryAttribute read FUf;
    property Ibge: TDictionaryAttribute read FIbge;
    property FkUsuario: TDictionaryAssociation read FFkUsuario;
  end;

function Dic: TDicDictionary;

implementation

var
  __Dic: TDicDictionary;

function Dic: TDicDictionary;
begin
  if __Dic = nil then
    __Dic := TDicDictionary.Create;
  result := __Dic
end;

{ TConexao }

function TConexao.GetFkUsuario: TUsuario;
begin
  result := FFkUsuario.Value;
end;

procedure TConexao.SetFkUsuario(const Value: TUsuario);
begin
  FFkUsuario.Value := Value;
end;

function TConexao.GetFkEstabelecimento: TEstabelecimento;
begin
  result := FFkEstabelecimento.Value;
end;

procedure TConexao.SetFkEstabelecimento(const Value: TEstabelecimento);
begin
  FFkEstabelecimento.Value := Value;
end;

{ TEmail }

function TEmail.GetFkUsuario: TUsuario;
begin
  result := FFkUsuario.Value;
end;

procedure TEmail.SetFkUsuario(const Value: TUsuario);
begin
  FFkUsuario.Value := Value;
end;

{ TEndereco }

function TEndereco.GetFkUsuario: TUsuario;
begin
  result := FFkUsuario.Value;
end;

procedure TEndereco.SetFkUsuario(const Value: TUsuario);
begin
  FFkUsuario.Value := Value;
end;

{ TEstabelecimento }

function TEstabelecimento.GetFkGrupoEstabelecimento: TGrupoEstabelecimento;
begin
  result := FFkGrupoEstabelecimento.Value;
end;

procedure TEstabelecimento.SetFkGrupoEstabelecimento(const Value: TGrupoEstabelecimento);
begin
  FFkGrupoEstabelecimento.Value := Value;
end;

constructor TEstabelecimento.Create;
begin
  inherited;
  FListaConexao := TList<TConexao>.Create;
end;

destructor TEstabelecimento.Destroy;
begin
  FListaConexao.Free;
  inherited;
end;

{ TIdentificador }

function TIdentificador.GetFkUsuario: TUsuario;
begin
  result := FFkUsuario.Value;
end;

procedure TIdentificador.SetFkUsuario(const Value: TUsuario);
begin
  FFkUsuario.Value := Value;
end;

{ TTelefone }

function TTelefone.GetFkUsuario: TUsuario;
begin
  result := FFkUsuario.Value;
end;

procedure TTelefone.SetFkUsuario(const Value: TUsuario);
begin
  FFkUsuario.Value := Value;
end;

{ TToken }

function TToken.GetFkUsuario: TUsuario;
begin
  result := FFkUsuario.Value;
end;

procedure TToken.SetFkUsuario(const Value: TUsuario);
begin
  FFkUsuario.Value := Value;
end;

function TToken.GetFkEstabelecimento: TEstabelecimento;
begin
  result := FFkEstabelecimento.Value;
end;

procedure TToken.SetFkEstabelecimento(const Value: TEstabelecimento);
begin
  FFkEstabelecimento.Value := Value;
end;

{ TUsuario }

function TUsuario.GetFkUsuarioAdc: TUsuarioAdc;
begin
  result := FFkUsuarioAdc.Value;
end;

procedure TUsuario.SetFkUsuarioAdc(const Value: TUsuarioAdc);
begin
  FFkUsuarioAdc.Value := Value;
end;

constructor TUsuario.Create;
begin
  inherited;
  FListaIdentificador := TList<TIdentificador>.Create;
  FListaConexao := TList<TConexao>.Create;
  FListaEmail := TList<TEmail>.Create;
  FListaTelefone := TList<TTelefone>.Create;
  FListaEndereco := TList<TEndereco>.Create;
end;

destructor TUsuario.Destroy;
begin
  FListaEndereco.Free;
  FListaTelefone.Free;
  FListaEmail.Free;
  FListaConexao.Free;
  FListaIdentificador.Free;
  inherited;
end;

{ TDicDictionary }

destructor TDicDictionary.Destroy;
begin
  if FEndereco <> nil then
    FEndereco.Free;
  if FToken <> nil then
    FToken.Free;
  if FEstabelecimento <> nil then
    FEstabelecimento.Free;
  if FGrupoEstabelecimento <> nil then
    FGrupoEstabelecimento.Free;
  if FUsuarioAdc <> nil then
    FUsuarioAdc.Free;
  if FTelefone <> nil then
    FTelefone.Free;
  if FEmail <> nil then
    FEmail.Free;
  if FConexao <> nil then
    FConexao.Free;
  if FIdentificador <> nil then
    FIdentificador.Free;
  if FUsuario <> nil then
    FUsuario.Free;
  inherited;
end;

function TDicDictionary.GetUsuario: TUsuarioTableDictionary;
begin
  if FUsuario = nil then
    FUsuario := TUsuarioTableDictionary.Create;
  result := FUsuario;
end;

function TDicDictionary.GetIdentificador: TIdentificadorTableDictionary;
begin
  if FIdentificador = nil then
    FIdentificador := TIdentificadorTableDictionary.Create;
  result := FIdentificador;
end;

function TDicDictionary.GetConexao: TConexaoTableDictionary;
begin
  if FConexao = nil then
    FConexao := TConexaoTableDictionary.Create;
  result := FConexao;
end;

function TDicDictionary.GetEmail: TEmailTableDictionary;
begin
  if FEmail = nil then
    FEmail := TEmailTableDictionary.Create;
  result := FEmail;
end;

function TDicDictionary.GetTelefone: TTelefoneTableDictionary;
begin
  if FTelefone = nil then
    FTelefone := TTelefoneTableDictionary.Create;
  result := FTelefone;
end;

function TDicDictionary.GetUsuarioAdc: TUsuarioAdcTableDictionary;
begin
  if FUsuarioAdc = nil then
    FUsuarioAdc := TUsuarioAdcTableDictionary.Create;
  result := FUsuarioAdc;
end;

function TDicDictionary.GetGrupoEstabelecimento: TGrupoEstabelecimentoTableDictionary;
begin
  if FGrupoEstabelecimento = nil then
    FGrupoEstabelecimento := TGrupoEstabelecimentoTableDictionary.Create;
  result := FGrupoEstabelecimento;
end;

function TDicDictionary.GetEstabelecimento: TEstabelecimentoTableDictionary;
begin
  if FEstabelecimento = nil then
    FEstabelecimento := TEstabelecimentoTableDictionary.Create;
  result := FEstabelecimento;
end;

function TDicDictionary.GetToken: TTokenTableDictionary;
begin
  if FToken = nil then
    FToken := TTokenTableDictionary.Create;
  result := FToken;
end;

function TDicDictionary.GetEndereco: TEnderecoTableDictionary;
begin
  if FEndereco = nil then
    FEndereco := TEnderecoTableDictionary.Create;
  result := FEndereco;
end;

{ TUsuarioTableDictionary }

constructor TUsuarioTableDictionary.Create;
begin
  inherited;
  FIdUsuario := TDictionaryAttribute.Create('IdUsuario');
  FCodigo := TDictionaryAttribute.Create('Codigo');
  FClasse := TDictionaryAttribute.Create('Classe');
  FNomeRazao := TDictionaryAttribute.Create('NomeRazao');
  FFantasia := TDictionaryAttribute.Create('Fantasia');
  FCpfCnpj := TDictionaryAttribute.Create('CpfCnpj');
  FRgIe := TDictionaryAttribute.Create('RgIe');
  FStatus := TDictionaryAttribute.Create('Status');
  FSexo := TDictionaryAttribute.Create('Sexo');
  FSenha := TDictionaryAttribute.Create('Senha');
  FFkToken := TDictionaryAttribute.Create('FkToken');
  FFkUsuarioAdc := TDictionaryAssociation.Create('FkUsuarioAdc');
end;

{ TIdentificadorTableDictionary }

constructor TIdentificadorTableDictionary.Create;
begin
  inherited;
  FIdFuncao := TDictionaryAttribute.Create('IdFuncao');
  FIdentificador := TDictionaryAttribute.Create('Identificador');
  FFkUsuario := TDictionaryAssociation.Create('FkUsuario');
end;

{ TConexaoTableDictionary }

constructor TConexaoTableDictionary.Create;
begin
  inherited;
  FIdUrlConexao := TDictionaryAttribute.Create('IdUrlConexao');
  FUrl := TDictionaryAttribute.Create('Url');
  FFkUsuario := TDictionaryAssociation.Create('FkUsuario');
  FFkEstabelecimento := TDictionaryAssociation.Create('FkEstabelecimento');
end;

{ TEmailTableDictionary }

constructor TEmailTableDictionary.Create;
begin
  inherited;
  FIdEmail := TDictionaryAttribute.Create('IdEmail');
  FEmail := TDictionaryAttribute.Create('Email');
  FIdentificador := TDictionaryAttribute.Create('Identificador');
  FFkUsuario := TDictionaryAssociation.Create('FkUsuario');
end;

{ TTelefoneTableDictionary }

constructor TTelefoneTableDictionary.Create;
begin
  inherited;
  FIdTelefone := TDictionaryAttribute.Create('IdTelefone');
  FCodPais := TDictionaryAttribute.Create('CodPais');
  FDdd := TDictionaryAttribute.Create('Ddd');
  FTelefone := TDictionaryAttribute.Create('Telefone');
  FIdentificador := TDictionaryAttribute.Create('Identificador');
  FFkUsuario := TDictionaryAssociation.Create('FkUsuario');
end;

{ TUsuarioAdcTableDictionary }

constructor TUsuarioAdcTableDictionary.Create;
begin
  inherited;
  FIdUsuarioAdc := TDictionaryAttribute.Create('IdUsuarioAdc');
  FIndIe := TDictionaryAttribute.Create('IndIe');
  FInscricaoMunicipal := TDictionaryAttribute.Create('InscricaoMunicipal');
  FDtCadastro := TDictionaryAttribute.Create('DtCadastro');
  FDtNascimento := TDictionaryAttribute.Create('DtNascimento');
  FDtAdmissaoFuncionario := TDictionaryAttribute.Create('DtAdmissaoFuncionario');
  FDtDemissaoFuncionario := TDictionaryAttribute.Create('DtDemissaoFuncionario');
  FComissaoFuncionario := TDictionaryAttribute.Create('ComissaoFuncionario');
  FSalarioFuncionario := TDictionaryAttribute.Create('SalarioFuncionario');
  FFuncaoFuncionario := TDictionaryAttribute.Create('FuncaoFuncionario');
  FNivelUsuario := TDictionaryAttribute.Create('NivelUsuario');
  FPersonalizadoUsuario := TDictionaryAttribute.Create('PersonalizadoUsuario');
end;

{ TGrupoEstabelecimentoTableDictionary }

constructor TGrupoEstabelecimentoTableDictionary.Create;
begin
  inherited;
  FIdGrupoEstabelecimento := TDictionaryAttribute.Create('IdGrupoEstabelecimento');
  FDescricao := TDictionaryAttribute.Create('Descricao');
end;

{ TEstabelecimentoTableDictionary }

constructor TEstabelecimentoTableDictionary.Create;
begin
  inherited;
  FIdEstabelecimento := TDictionaryAttribute.Create('IdEstabelecimento');
  FClasse := TDictionaryAttribute.Create('Classe');
  FCnpjCpf := TDictionaryAttribute.Create('CnpjCpf');
  FRazao := TDictionaryAttribute.Create('Razao');
  FFantasia := TDictionaryAttribute.Create('Fantasia');
  FIe := TDictionaryAttribute.Create('Ie');
  FIm := TDictionaryAttribute.Create('Im');
  FFkGrupoEstabelecimento := TDictionaryAssociation.Create('FkGrupoEstabelecimento');
end;

{ TTokenTableDictionary }

constructor TTokenTableDictionary.Create;
begin
  inherited;
  FIdToken := TDictionaryAttribute.Create('IdToken');
  FFkUsuario := TDictionaryAssociation.Create('FkUsuario');
  FFkEstabelecimento := TDictionaryAssociation.Create('FkEstabelecimento');
end;

{ TEnderecoTableDictionary }

constructor TEnderecoTableDictionary.Create;
begin
  inherited;
  FIdEndereco := TDictionaryAttribute.Create('IdEndereco');
  FDescricao := TDictionaryAttribute.Create('Descricao');
  FCep := TDictionaryAttribute.Create('Cep');
  FLogradouro := TDictionaryAttribute.Create('Logradouro');
  FNumero := TDictionaryAttribute.Create('Numero');
  FBairro := TDictionaryAttribute.Create('Bairro');
  FCidade := TDictionaryAttribute.Create('Cidade');
  FComplemento := TDictionaryAttribute.Create('Complemento');
  FReferencia := TDictionaryAttribute.Create('Referencia');
  FUf := TDictionaryAttribute.Create('Uf');
  FIbge := TDictionaryAttribute.Create('Ibge');
  FFkUsuario := TDictionaryAssociation.Create('FkUsuario');
end;

initialization

RegisterEntity(TUsuario);
RegisterEntity(TIdentificador);
RegisterEntity(TConexao);
RegisterEntity(TEmail);
RegisterEntity(TTelefone);
RegisterEntity(TUsuarioAdc);
RegisterEntity(TGrupoEstabelecimento);
RegisterEntity(TEstabelecimento);
RegisterEntity(TToken);
RegisterEntity(TEndereco);

finalization

if __Dic <> nil then
  __Dic.Free

end.
